import pytest
import unittest

from promptflow.connections import CustomConnection
from my_tool_package.tools.my_tool_1 import my_tool


@pytest.fixture
def my_custom_connection() -> CustomConnection:
    my_custom_connection = CustomConnection(
        {
            "api-key" : "my-api-key",
            "api-secret" : "my-api-secret",
            "api-url" : "my-api-url"
        }
    )
    return my_custom_connection


class TestMyTool1:
    def test_my_tool_1(self, my_custom_connection):
        result = my_tool(my_custom_connection, input_text="Microsoft")
        assert result == "Hello Microsoft"


# Run the unit tests
if __name__ == "__main__":
    unittest.main()



from promptflow import ToolProvider, tool
from promptflow.connections import CustomConnection


class MyTool(ToolProvider):
    """
    Doc reference :
    """

    def __init__(self, connection: CustomConnection):
        super().__init__()
        self.connection = connection

    @tool
    def my_tool(self, input_text: str) -> str:
        # Replace with your tool code.
        # Usually connection contains configs to connect to an API.
        # Use CustomConnection is a dict. You can use it like: connection.api_key, connection.api_base
        # Not all tools need a connection. You can remove it if you don't need it.
        return "Hello " + input_text



from setuptools import find_packages, setup

PACKAGE_NAME = "oeahr-package"

setup(
    name=PACKAGE_NAME,
    version="0.0.7",
    description="This is my tools package",
    packages=find_packages(),
    entry_points={
        "package_tools": ["my_tools = my_tool_package.tools.utils:list_package_tools"],
    },
    include_package_data=True,  # This line tells setuptools to include files from MANIFEST.in
)



from promptflow import tool
from promptflow.connections import CustomConnection


@tool
def my_tool(connection: CustomConnection, input_text: str) -> str:
    # Replace with your tool code.
    # Usually connection contains configs to connect to an API.
    # Use CustomConnection is a dict. You can use it like: connection.api_key, connection.api_base
    # Not all tools need a connection. You can remove it if you don't need it.
    return "Hello " + input_text
